@@ -1,3 +1,8 @@
+#if defined( HAVE_CONFIG_H )
+# include "config.h"
+#endif
+
+#include <kdemacros.h>
 #include <gmodule.h>
 #include <stdio.h>
 #include "qt_rc_style.h"
@@ -5,25 +10,24 @@
 
 #include "qt_qt_wrapper.h"
 
-G_MODULE_EXPORT void theme_init (GTypeModule *module);
-G_MODULE_EXPORT void theme_exit (void);
-G_MODULE_EXPORT GtkRcStyle * theme_create_rc_style (void);
+KDE_EXPORT void theme_init (GTypeModule *module);
+KDE_EXPORT void theme_exit (void);
+KDE_EXPORT GtkRcStyle * theme_create_rc_style (void);
 
-G_MODULE_EXPORT void theme_init (GTypeModule *module)
+KDE_EXPORT void theme_init (GTypeModule *module)
 {
 	createTQApp();
 	qtengine_rc_style_register_type (module);
 	qtengine_style_register_type (module);
 }
 
-G_MODULE_EXPORT void theme_exit (void)
+KDE_EXPORT void theme_exit (void)
 {
 	destroyTQApp();
 }
 
-G_MODULE_EXPORT GtkRcStyle * theme_create_rc_style (void)
+KDE_EXPORT GtkRcStyle * theme_create_rc_style (void)
 {
 	void *ptr = GTK_RC_STYLE (g_object_new (TQTENGINE_TYPE_RC_STYLE, NULL));  
 	return (GtkRcStyle *)ptr;
 }
-
